Vlasiator ebf0dd394 on dev (v5.4.0 + 1054 commits)
Loading...
Searching...
No Matches
cpu_1d_ppm_nonuniform_conserving.hpp
Go to the documentation of this file.
1/*
2 * This file is part of Vlasiator.
3 * Copyright 2010-2016 Finnish Meteorological Institute
4 *
5 * For details of usage, see the COPYING file and read the "Rules of the Road"
6 * at http://www.physics.helsinki.fi/vlasiator/
7 *
8 * This program is free software; you can redistribute it and/or modify
9 * it under the terms of the GNU General Public License as published by
10 * the Free Software Foundation; either version 2 of the License, or
11 * (at your option) any later version.
12 *
13 * This program is distributed in the hope that it will be useful,
14 * but WITHOUT ANY WARRANTY; without even the implied warranty of
15 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
16 * GNU General Public License for more details.
17 *
18 * You should have received a copy of the GNU General Public License along
19 * with this program; if not, write to the Free Software Foundation, Inc.,
20 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
21 */
22
23#ifndef CPU_1D_PPM_H
24#define CPU_1D_PPM_H
25
26#include <iostream>
27#include "vec.h"
28#include "algorithm"
29#include "cmath"
30
33
34using namespace std;
35
36/*
37 Compute parabolic reconstruction with an explicit scheme
38*/
39inline void compute_ppm_coeff_nonuniform(const Vec * const dv, const Vec * const values, const face_estimate_order order,const uint k, Vec a[3], const Realf threshold){
40 Vec m_face; /*left face value*/
41 Vec p_face; /*right face value*/
42 compute_filtered_face_values_nonuniform_conserving(dv, values, k, order, m_face, p_face, threshold);
43
44 //Coella et al, check for monotonicity
45 // m_face = select((p_face - m_face) * (values[k] - 0.5 * (m_face + p_face)) >
46 // (p_face - m_face)*(p_face - m_face) * one_sixth,
47 // 3 * values[k] - 2 * p_face,
48 // m_face);
49 // p_face = select(-(p_face - m_face) * (p_face - m_face) * one_sixth >
50 // (p_face - m_face) * (values[k] - 0.5 * (m_face + p_face)),
51 // 3 * values[k] - 2 * m_face,
52 // p_face);
53
54 //Fit a second order polynomial for reconstruction see, e.g., White
55 //2008 (PQM article) (note additional integration factors built in,
56 //contrary to White (2008) eq. 4
57 a[0] = m_face;
58 a[1] = 3.0 * values[k] - 2.0 * m_face - p_face;
59 a[2] = (m_face + p_face - 2.0 * values[k]);
60}
61
62
63#endif
void compute_ppm_coeff_nonuniform(const Vec *const dv, const Vec *const values, const face_estimate_order order, const uint k, Vec a[3], const Realf threshold)
face_estimate_order
void compute_filtered_face_values_nonuniform_conserving(const Realf *const dv, const Vec *const values, const uint k, const face_estimate_order order, Vec &fv_l, Vec &fv_r, const Realf threshold)
float Realf
Definition definitions.h:33
__global__ void vmesh::VelocityMesh **__restrict__ ColumnOffsets split::SplitVector< vmesh::GlobalID > Hashinator::Hashmap< vmesh::GlobalID, vmesh::LocalID > const uint *__restrict__ const Realf const int const int const Realf const Realf dv
const int k
__global__ void const Realf const uint *__restrict__ const uint *__restrict__ const vmesh::GlobalID *__restrict__ const uint const uint const uint const Realf threshold
An interface to a type with floating point values.